diff --git a/doc/src/sgml/queries.sgml b/doc/src/sgml/queries.sgml
index d7b0d73..acc6686 100644
--- a/doc/src/sgml/queries.sgml
+++ b/doc/src/sgml/queries.sgml
@@ -549,7 +549,7 @@ SELECT * FROM my_table AS m WHERE my_table.a &gt; 5;    -- wrong
 SELECT * FROM people AS mother JOIN people AS child ON mother.id = child.mother_id;
 </programlisting>
      Additionally, an alias is required if the table reference is a
-     subquery (see <xref linkend="queries-subqueries">).
+     subquery (see <xref linkend="queries-subquery-derived-tables">).
     </para>
 
     <para>
@@ -590,10 +590,10 @@ SELECT a.* FROM (my_table AS a JOIN your_table AS b ON ...) AS c
     </para>
    </sect3>
 
-   <sect3 id="queries-subqueries">
-    <title>Subqueries</title>
+   <sect3 id="queries-subquery-derived-tables">
+    <title>Subquery Derived Tables</title>
 
-    <indexterm zone="queries-subqueries">
+    <indexterm zone="queries-subquery-derived-tables">
      <primary>subquery</primary>
     </indexterm>
 
@@ -1315,6 +1315,46 @@ SELECT DISTINCT ON (<replaceable>expression</replaceable> <optional>, <replaceab
  </sect1>
 
 
+ <sect1 id="queries-subqueries">
+  <title>Subqueries</title>
+
+  <indexterm zone="queries-subqueries">
+   <primary>subquery</primary>
+  </indexterm>
+
+  <indexterm zone="queries-subqueries">
+   <primary>sub-select</primary>
+  </indexterm>
+
+  <para>
+   Subqueries, also called sub-selects, are queries written within
+   parenthesis in the text of larger queries.  The values produced by
+   subqueries may be scalar, used within expressions as described
+   in <xref linkend="sql-syntax-scalar-subqueries">, or tabular.  When
+   tabular, subqueries may substitute for tables, as described
+   in <xref linkend="queries-subquery-derived-tables">, generate array
+   content, as described
+   in <xref linkend="sql-syntax-array-constructors">, have their
+   result content tested within expressions, as described
+   in <xref linkend="functions-subquery">, or be used in other
+   contexts.  Often either joins or subqueries can be used to produce
+   different query plans yielding identical output.  Which technique
+   is appropriate depends upon circumstance but it is worth noting
+   that more work has gone into query planner join optimization.
+  </para>
+
+  <para>
+   Subqueries may not modify database
+   content.  <link linkend="queries-with">Common Table
+   Expressions</link> are one way to integrate data returned by data
+   modification statements,
+   i.e. <command>INSERT</command>/<command>UPDATE</command>/<command>DELETE</command>
+   statements with <literal>RETURNING</literal> clauses, into larger
+   queries.
+  </para>
+ </sect1>
+
+
  <sect1 id="queries-union">
   <title>Combining Queries</title>
 
